instrumenttools.BassClarinet
============================

.. inheritance-diagram:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet
   :private-bases:

.. autoclass:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.default_instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.default_short_instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.effective_context

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.interval_of_transposition

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.is_primary_instrument

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.is_secondary_instrument

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.is_transposing

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.lilypond_format

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.start_component

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.target_context

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.traditional_pitch_range

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.all_clefs

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.instrument_name_markup

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.pitch_range

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.primary_clefs

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.short_instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.short_instrument_name_markup

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.sounding_pitch_of_fingered_middle_c

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Methods
-------

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.attach

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.detach

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.get_default_performer_name

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.get_performer_names

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__call__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__delattr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__eq__

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__hash__

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__ne__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__repr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`
